@@ -11,8 +11,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1301, USA.
 
     ---
     Copyright (C) 2004, Anders Lund <anders@alweb.dk>
@@ -665,7 +665,7 @@ KateTemplateWizard::KateTemplateWizard( QWidget *parent, KateFileTemplates *kft
   // Hide the help button for now
   helpButton()->hide();
 
-  // 1) Optionally chose a file or existing template to start from
+  // 1) Optionally choose a file or existing template to start from
   QWidget *page = new QWidget( this );
   QGridLayout *glo = new QGridLayout( page );
   //lo->setAutoAdd( true );
@@ -721,7 +721,7 @@ KateTemplateWizard::KateTemplateWizard( QWidget *parent, KateFileTemplates *kft
 
   glo->addMultiCell( new QSpacerItem( 1, 1, QSizePolicy::Expanding, QSizePolicy::Expanding ), 7, 7, 1, 2 );
 
-  addPage( page, i18n("Chose Template Origin") );
+  addPage( page, i18n("Choose Template Origin") );
   kdDebug()<<"=== Adding template origin page at "<<page<<endl;
   // 2) edit the template properties
   kti = new KateTemplateInfoWidget( this, 0, kft );
@@ -740,13 +740,13 @@ KateTemplateWizard::KateTemplateWizard( QWidget *parent, KateFileTemplates *kft
     _s += " <" + sEmail + ">";
   kti->leAuthor->setText( _s );
 
-  // 3) chose a location - either the template directory (default) or
+  // 3) choose a location - either the template directory (default) or
   // a custom location
   page = new QWidget( this );
   glo = new QGridLayout( page, 7, 2 );
   glo->setSpacing( KDialogBase::spacingHint() );
 
-  glo->addMultiCellWidget( new QLabel( i18n("<p>Chose a location for the "
+  glo->addMultiCellWidget( new QLabel( i18n("<p>Choose a location for the "
       "template. If you store it in the template directory, it will "
       "automatically be added to the template menu.</p>"), page ), 1, 1, 1, 2);
 
@@ -1082,8 +1082,8 @@ class KateTemplateItem : public KListViewItem
 //BEGIN KFTNewStuff
 class KFTNewStuff : public KNewStuff {
   public:
-    KFTNewStuff( const QString &type, QWidget *parent=0 ) : KNewStuff( type, parent ), m_win( parent ) {};
-    ~KFTNewStuff() {};
+    KFTNewStuff( const QString &type, QWidget *parent=0 ) : KNewStuff( type, parent ), m_win( parent ) {}
+    ~KFTNewStuff() {}
     bool install( const QString &/*filename*/ ) { return true; }
     bool createUploadFile( const QString &/*filename*/ ) { return false; }
     QString downloadDestination( KNS::Entry *entry )
