@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- *  $Id: kfile_html.cpp 481510 2005-11-19 10:44:24Z coolo $
+ *  $Id: kfile_html.cpp 607813 2006-11-25 21:00:52Z mkoller $
  */
 
 #include "kfile_html.h"
@@ -28,6 +28,7 @@
 #include <qcstring.h>
 #include <qfile.h>
 #include <qregexp.h>
+#include <qtextcodec.h>
 
 typedef KGenericFactory<KHtmlPlugin> HtmlFactory;
 
@@ -73,7 +74,7 @@ bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
     f.readBlock(data.data(), maxBufSize);
     data[maxBufSize]='\0';
 
-    QString s(data.data());
+    QString s(data);
 
     int start=0, last=0;
     QRegExp exp;
@@ -90,10 +91,11 @@ bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
         last += exp.matchedLength();
     }
 
+    QString title;
     exp.setPattern("<\\s*title\\s*>\\s*(.*)\\s*<\\s*/\\s*title\\s*>");
     if (exp.search(s, last) != -1)
     {
-        appendItem(group, "Title", exp.cap(1));
+        title = exp.cap(1);
         last += exp.matchedLength();
     }
 
@@ -101,8 +103,10 @@ bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
 
     QString meta, name, content;
     exp.setPattern("<\\s*meta\\s*([^>]*)\\s*>");
-    QRegExp rxName = QRegExp("(?:name|http-equiv)\\s*=\\s*\"([^\"]+)\"");
-    QRegExp rxContent = QRegExp("content\\s*=\\s*\"([^\"]+)\"");
+    QRegExp rxName("(?:name|http-equiv)\\s*=\\s*\"([^\"]+)\"", false);
+    QRegExp rxContent("content\\s*=\\s*\"([^\"]+)\"", false);
+    QRegExp rxCharset("charset\\s*=\\s*(.*)", false);
+    QTextCodec *codec = 0;
 
     // find the meta tags
     last = 0;
@@ -124,6 +128,24 @@ bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
         content = rxContent.cap(1);
 
         appendItem(metatags, name, content.left(50));
+
+        // check if it has a charset defined
+        if ( rxCharset.search(content) != -1 )
+        {
+            kdDebug(7034) << "CodecForName : " << rxCharset.cap(1) << endl;
+            codec = QTextCodec::codecForName(rxCharset.cap(1).ascii());
+        }
+    }
+
+    if ( ! title.isEmpty() )
+    {
+        if ( codec )
+        {
+          title = codec->toUnicode(title.ascii());
+          kdDebug(7034) << "Codec : " << codec->name() << endl;
+        }
+
+        appendItem(group, "Title", title);
     }
 
     // find out if it contains javascript
