@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <dcopclient.h>
@@ -123,109 +123,100 @@ void SettingsPlugin::showPopup()
 
   if (!mConfig)
     mConfig = new KConfig("settingspluginrc", false, false);
+    
+  KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
 
-    KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
+  KProtocolManager::reparseConfiguration();
+  bool cookies = cookiesEnabled( part->url().url() );
 
-    KProtocolManager::reparseConfiguration();
-    bool cookies = cookiesEnabled( part->url().url() );
+  ((KToggleAction*)actionCollection()->action("useproxy"))->setChecked(KProtocolManager::useProxy());
+  ((KToggleAction*)actionCollection()->action("java"))->setChecked( part->javaEnabled() );
+  ((KToggleAction*)actionCollection()->action("javascript"))->setChecked( part->jScriptEnabled() );
+  ((KToggleAction*)actionCollection()->action("cookies"))->setChecked( cookies );
+  ((KToggleAction*)actionCollection()->action("plugins"))->setChecked( part->pluginsEnabled() );
+  ((KToggleAction*)actionCollection()->action("imageloading"))->setChecked( part->autoloadImages() );
+  ((KToggleAction*)actionCollection()->action("usecache"))->setChecked(KProtocolManager::useCache());
 
-    ((KToggleAction*)actionCollection()->action("useproxy"))->setChecked(KProtocolManager::useProxy());
-    ((KToggleAction*)actionCollection()->action("java"))->setChecked( part->javaEnabled() );
-    ((KToggleAction*)actionCollection()->action("javascript"))->setChecked( part->jScriptEnabled() );
-    ((KToggleAction*)actionCollection()->action("cookies"))->setChecked( cookies );
-    ((KToggleAction*)actionCollection()->action("plugins"))->setChecked( part->pluginsEnabled() );
-    ((KToggleAction*)actionCollection()->action("imageloading"))->setChecked( part->autoloadImages() );
-    ((KToggleAction*)actionCollection()->action("usecache"))->setChecked(KProtocolManager::useCache());
-
-    KIO::CacheControl cc = KProtocolManager::cacheControl();
-  switch ( cc )
+  KIO::CacheControl cc = KProtocolManager::cacheControl();
+  switch ( cc ) 
   {
-        case KIO::CC_Verify:
-            ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 0 );
-            break;
-        case KIO::CC_CacheOnly:
-            ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 2 );
-            break;
-        case KIO::CC_Cache:
-            ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 1 );
-            break;
-        case KIO::CC_Reload: // nothing for now
-        case KIO::CC_Refresh:
+      case KIO::CC_Verify:
+          ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 0 );
+          break;
+      case KIO::CC_CacheOnly:
+          ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 2 );
+          break;
+      case KIO::CC_Cache:
+          ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 1 );
+          break;
+      case KIO::CC_Reload: // nothing for now
+      case KIO::CC_Refresh:
       default:
-            break;
-
+          break;
+      
   }
 }
 
 void SettingsPlugin::toggleJava()
 {
   if( parent() && parent()->inherits("KHTMLPart"))
-    {
-       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
-        part->setJavaEnabled( ((KToggleAction*)actionCollection()->action("java"))->isChecked() );
-    }
+  {
+      KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+      part->setJavaEnabled( ((KToggleAction*)actionCollection()->action("java"))->isChecked() );
+  }
 }
 
 void SettingsPlugin::toggleJavascript()
 {
   if( parent() && parent()->inherits("KHTMLPart"))
-    {
-       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
-       part->setJScriptEnabled( ((KToggleAction*)actionCollection()->action("javascript"))->isChecked() );
-    }
+  {
+      KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+      part->setJScriptEnabled( ((KToggleAction*)actionCollection()->action("javascript"))->isChecked() );
+  }
 }
 
 void SettingsPlugin::toggleCookies()
 {
   if( !parent() || !parent()->inherits("KHTMLPart"))
     return;
+    
+  KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
 
-    KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
+  QString advice;
+  bool enable = ((KToggleAction*)actionCollection()->action("cookies"))->isChecked();
+  advice = enable ? "Accept" : "Reject";
 
-    QString advice;
-    bool enable = ((KToggleAction*)actionCollection()->action("cookies"))->isChecked();
-    advice = enable ? "Accept" : "Reject";
+  QCString replyType;
+  QByteArray data, replyData;
+  QDataStream stream( data, IO_WriteOnly );
+  stream << part->url().url() << advice;
+  bool ok = kapp->dcopClient()->call( "kded", "kcookiejar",
+        "setDomainAdvice(QString,QString)",
+        data, replyType, replyData, true );
 
-    QCString replyType;
-    QByteArray data, replyData;
-    QDataStream stream( data, IO_WriteOnly );
-    stream << part->url().url() << advice;
-    bool ok = kapp->dcopClient()->call( "kcookiejar", "kcookiejar",
-					"setDomainAdvice(QString,QString)",
-					data, replyType, replyData, true );
-
-    // cookies disabled completely -> we have to start kcookiejar
-    if ( !ok && enable ) {
-	ok = ( kapp->startServiceByDesktopName("kcookiejar") == 0 );
-	if ( ok )
-	    ok = kapp->dcopClient()->call( "kcookiejar", "kcookiejar",
-					   "setDomainAdvice(QString,QString)",
-					   data, replyType, replyData, true );
-
-	if ( !ok )
-	    KMessageBox::sorry( part->widget(),
-				i18n("I can't enable cookies, because the "
-				     "cookie daemon could not be started."),
-				i18n("Cookies Disabled"));
-    }
+  if ( !ok )
+     KMessageBox::sorry( part->widget(),
+          i18n("I can't enable cookies, because the "
+                "cookie daemon could not be started."),
+          i18n("Cookies Disabled"));
 }
 
 void SettingsPlugin::togglePlugins()
 {
   if( parent() && parent()->inherits("KHTMLPart"))
-    {
-       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
-        part->setPluginsEnabled( ((KToggleAction*)actionCollection()->action("plugins"))->isChecked() );
-    }
+  {
+      KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+      part->setPluginsEnabled( ((KToggleAction*)actionCollection()->action("plugins"))->isChecked() );
+  }
 }
 
 void SettingsPlugin::toggleImageLoading()
 {
   if( parent() && parent()->inherits("KHTMLPart"))
-    {
-       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
-        part->setAutoloadImages( ((KToggleAction*)actionCollection()->action("imageloading"))->isChecked() );
-    }
+  {
+      KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+      part->setAutoloadImages( ((KToggleAction*)actionCollection()->action("imageloading"))->isChecked() );
+  }
 }
 
 bool SettingsPlugin::cookiesEnabled( const QString& url )
@@ -238,18 +229,19 @@ bool SettingsPlugin::cookiesEnabled( const QString& url )
 
     bool enabled = false;
 
-    if ( replyType == "QString" ) {
-	QString advice;
-	QDataStream s( reply, IO_ReadOnly );
-	s >> advice;
-	enabled = ( advice == "Accept" );
-	if ( !enabled && advice == "Dunno" ) {
-	    // TODO, check the global setting via dcop
-	    KConfig kc( "kcookiejarrc", true, false );
-	    kc.setGroup( "Cookie Policy" );
-	    enabled =
-		(kc.readEntry( "CookieGlobalAdvice", "Reject" ) == "Accept");
-	}
+    if ( replyType == "QString" ) 
+    {
+        QString advice;
+        QDataStream s( reply, IO_ReadOnly );
+        s >> advice;
+        enabled = ( advice == "Accept" );
+        if ( !enabled && advice == "Dunno" ) {
+            // TODO, check the global setting via dcop
+            KConfig kc( "kcookiejarrc", true, false );
+            kc.setGroup( "Cookie Policy" );
+            enabled =
+          (kc.readEntry( "CookieGlobalAdvice", "Reject" ) == "Accept");
+        }
     }
 
     return enabled;
@@ -262,10 +254,10 @@ bool SettingsPlugin::cookiesEnabled( const QString& url )
 
 void SettingsPlugin::toggleProxy()
 {
-    bool enable = ((KToggleAction*)actionCollection()->action("useproxy"))->isChecked();
-
+    bool enable = ((KToggleAction*)actionCollection()->action("useproxy"))->isChecked();   
+    
     int type;
-
+    
     if( enable )
       type = mConfig->readNumEntry( "SavedProxyType", KProtocolManager::ManualProxy );
     else
@@ -273,9 +265,9 @@ void SettingsPlugin::toggleProxy()
       mConfig->writeEntry( "SavedProxyType", KProtocolManager::proxyType() );
       type = KProtocolManager::NoProxy;
     }
-
+    
     KConfig config("kioslaverc", false, false);
-    config.setGroup( "Proxy Settings" );
+    config.setGroup( "Proxy Settings" );    
     config.writeEntry( "ProxyType", type );
 
     ((KToggleAction*)actionCollection()->action("useproxy"))->setChecked(enable);
